@@ -51,7 +51,7 @@ static void
 _init_vaapi_context_debug (void)
 {
 #ifndef GST_DISABLE_GST_DEBUG
-  static volatile gsize _init = 0;
+  static gsize _init = 0;
 
   if (g_once_init_enter (&_init)) {
     GST_DEBUG_CATEGORY_INIT (gst_debug_vaapi_context, "vaapicontext", 0,
@@ -333,12 +333,12 @@ config_create (GstVaapiContext * context)
         string_of_va_chroma_format (va_chroma_format));
     goto cleanup;
   }
-  attrib->value = va_chroma_format;
+  attrib->value = value;
   attrib = &attribs[++attrib_index];
   g_assert (attrib_index < G_N_ELEMENTS (attribs));
 
   switch (cip->usage) {
-#if USE_ENCODERS
+#if GST_VAAPI_USE_ENCODERS
     case GST_VAAPI_CONTEXT_USAGE_ENCODE:
     {
       const GstVaapiConfigInfoEncoder *const config = &cip->config.encoder;
