@@ -305,10 +305,6 @@ decode_step (GstVaapiDecoder * decoder)
   gboolean got_frame;
   guint got_unit_size, input_size;
 
-  status = gst_vaapi_decoder_check_status (decoder);
-  if (status != GST_VAAPI_DECODER_STATUS_SUCCESS)
-    return status;
-
   /* Fill adapter with all buffers we have in the queue */
   for (;;) {
     buffer = pop_buffer (decoder);
@@ -424,14 +420,9 @@ set_caps (GstVaapiDecoder * decoder, const GstCaps * caps)
 {
   GstVideoCodecState *const codec_state = decoder->codec_state;
   GstStructure *const structure = gst_caps_get_structure (caps, 0);
-  GstVaapiProfile profile;
   const GValue *v_codec_data;
 
-  profile = gst_vaapi_profile_from_caps (caps);
-  if (!profile)
-    return FALSE;
-
-  decoder->codec = gst_vaapi_profile_get_codec (profile);
+  decoder->codec = gst_vaapi_get_codec_from_caps (caps);
   if (!decoder->codec)
     return FALSE;
 
@@ -483,7 +474,10 @@ gst_vaapi_decoder_finalize (GObject * object)
     decoder->frames = NULL;
   }
 
-  gst_vaapi_object_replace (&decoder->context, NULL);
+  if (decoder->context) {
+    gst_vaapi_context_unref (decoder->context);
+    decoder->context = NULL;
+  }
   decoder->va_context = VA_INVALID_ID;
 
   gst_vaapi_display_replace (&decoder->display, NULL);
@@ -529,7 +523,7 @@ gst_vaapi_decoder_get_property (GObject * object, guint property_id,
       g_value_set_object (value, decoder->display);
       break;
     case PROP_CAPS:
-      g_value_set_boxed (value, get_caps (decoder));
+      g_value_set_boxed (value, gst_caps_ref (get_caps (decoder)));
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -694,7 +688,7 @@ gst_vaapi_decoder_set_codec_state_changed_func (GstVaapiDecoder * decoder,
  * Retrieves the @decoder caps. The decoder owns the returned caps, so
  * use gst_caps_ref() whenever necessary.
  *
- * Return value: the @decoder caps
+ * Returns: (transfer none): the @decoder caps
  */
 GstCaps *
 gst_vaapi_decoder_get_caps (GstVaapiDecoder * decoder)
@@ -999,15 +993,6 @@ gst_vaapi_decoder_push_frame (GstVaapiDecoder * decoder,
   push_frame (decoder, frame);
 }
 
-GstVaapiDecoderStatus
-gst_vaapi_decoder_check_status (GstVaapiDecoder * decoder)
-{
-  if (decoder->context &&
-      gst_vaapi_context_get_surface_count (decoder->context) < 1)
-    return GST_VAAPI_DECODER_STATUS_ERROR_NO_SURFACE;
-  return GST_VAAPI_DECODER_STATUS_SUCCESS;
-}
-
 GstVaapiDecoderStatus
 gst_vaapi_decoder_parse (GstVaapiDecoder * decoder,
     GstVideoCodecFrame * base_frame, GstAdapter * adapter, gboolean at_eos,
@@ -1031,8 +1016,6 @@ gst_vaapi_decoder_parse (GstVaapiDecoder * decoder,
 GstVaapiDecoderStatus
 gst_vaapi_decoder_decode (GstVaapiDecoder * decoder, GstVideoCodecFrame * frame)
 {
-  GstVaapiDecoderStatus status;
-
   g_return_val_if_fail (decoder != NULL,
       GST_VAAPI_DECODER_STATUS_ERROR_INVALID_PARAMETER);
   g_return_val_if_fail (frame != NULL,
@@ -1040,9 +1023,6 @@ gst_vaapi_decoder_decode (GstVaapiDecoder * decoder, GstVideoCodecFrame * frame)
   g_return_val_if_fail (frame->user_data != NULL,
       GST_VAAPI_DECODER_STATUS_ERROR_INVALID_PARAMETER);
 
-  status = gst_vaapi_decoder_check_status (decoder);
-  if (status != GST_VAAPI_DECODER_STATUS_SUCCESS)
-    return status;
   return do_decode (decoder, frame);
 }
 
@@ -1139,24 +1119,6 @@ gst_vaapi_decoder_decode_codec_data (GstVaapiDecoder * decoder)
   return status;
 }
 
-/**
- * gst_vaapi_decoder_get_surface_formats:
- * @decoder: a #GstVaapiDecoder
- *
- * Retrieves an array of #GstVideoFormat which the output surfaces of
- * the @decoder can handle.
- *
- * Return value: (transfer full): a #GArray of #GstVideoFormat or
- * %NULL
- */
-GArray *
-gst_vaapi_decoder_get_surface_formats (GstVaapiDecoder * decoder)
-{
-  if (decoder && decoder->context)
-    return gst_vaapi_context_get_surface_formats (decoder->context);
-  return NULL;
-}
-
 /**
  * gst_vaapi_decoder_update_caps:
  * @decoder: a #GstVaapiDecoder
@@ -1175,7 +1137,6 @@ gboolean
 gst_vaapi_decoder_update_caps (GstVaapiDecoder * decoder, GstCaps * caps)
 {
   GstCaps *decoder_caps;
-  GstVaapiProfile profile;
   GstVaapiCodec codec;
 
   g_return_val_if_fail (decoder != NULL, FALSE);
@@ -1188,10 +1149,7 @@ gst_vaapi_decoder_update_caps (GstVaapiDecoder * decoder, GstCaps * caps)
   if (gst_caps_is_always_compatible (caps, decoder_caps))
     return set_caps (decoder, caps);
 
-  profile = gst_vaapi_profile_from_caps (caps);
-  if (profile == GST_VAAPI_PROFILE_UNKNOWN)
-    return FALSE;
-  codec = gst_vaapi_profile_get_codec (profile);
+  codec = gst_vaapi_get_codec_from_caps (caps);
   if (codec == 0)
     return FALSE;
   if (codec == decoder->codec) {
@@ -1204,3 +1162,52 @@ gst_vaapi_decoder_update_caps (GstVaapiDecoder * decoder, GstCaps * caps)
 
   return FALSE;
 }
+
+/**
+ * gst_vaapi_decoder_get_surface_attributres:
+ * @decoder: a #GstVaapiDecoder instances
+ * @min_width (out): the minimal surface width
+ * @min_height (out): the minimal surface height
+ * @max_width (out): the maximal surface width
+ * @max_height (out): the maximal surface height
+ *
+ * Fetches the valid surface's attributes for the current context.
+ *
+ * Returns: a #GArray of valid formats we get or %NULL if failed.
+ **/
+GArray *
+gst_vaapi_decoder_get_surface_attributes (GstVaapiDecoder * decoder,
+    gint * min_width, gint * min_height, gint * max_width, gint * max_height,
+    guint * mem_types)
+{
+  gboolean ret;
+  GstVaapiConfigSurfaceAttributes attribs = { 0, };
+
+  g_return_val_if_fail (decoder != NULL, FALSE);
+
+  if (!decoder->context)
+    return NULL;
+
+  ret = gst_vaapi_context_get_surface_attributes (decoder->context, &attribs);
+  if (ret)
+    attribs.formats = gst_vaapi_context_get_surface_formats (decoder->context);
+
+  if (!attribs.formats)
+    return NULL;
+  if (attribs.formats->len == 0) {
+    g_array_unref (attribs.formats);
+    return NULL;
+  }
+
+  if (min_width)
+    *min_width = attribs.min_width;
+  if (min_height)
+    *min_height = attribs.min_height;
+  if (max_width)
+    *max_width = attribs.max_width;
+  if (max_height)
+    *max_height = attribs.max_height;
+  if (mem_types)
+    *mem_types = attribs.mem_types;
+  return attribs.formats;
+}
